---
title: symbolicmodule
sidebarTitle: symbolicmodule
---

# `catalax.tools.symbolicmodule`

## Classes

### `SymbolicModule` <sup><a href="https://github.com/JR-1991/Catalax/blob/master/catalax/tools/symbolicmodule.py#L320" target="_blank"><Icon icon="github" style="width: 14px; height: 14px;" /></a></sup>

**Methods:**

#### `sympy` <sup><a href="https://github.com/JR-1991/Catalax/blob/master/catalax/tools/symbolicmodule.py#L369" target="_blank"><Icon icon="github" style="width: 14px; height: 14px;" /></a></sup>

```python
sympy(self) -> sympy.Expr
```
